@@ -98,6 +98,8 @@ class PolicyPlannerApis():
                                                                              self.workflow_id, workflow_task_id,
                                                                              ticket_id, workflow_packet_task_id)
         try:
+            if self.is_assigned(ticket_json):
+                self.unassign_pp_ticket(ticket_id)
             resp = requests.put(url=pp_tkt_url,
                                 headers=self.headers, data=user_id, verify=self.verify_ssl)
             return str(resp.status_code)
@@ -105,6 +107,34 @@ class PolicyPlannerApis():
             print("Exception occurred while assigning policy planner ticket with workflow id '{0}'\n Exception : {1}".
                   format(workflow_id, e.response.text))
 
+    def is_assigned(self, ticket_json: dict) -> bool:
+        """
+        Function to check if a ticket is assigned to the current user
+        :param ticket_json: JSON of targeted ticket
+        :param username: Username of current user
+        :return: True or False
+        """
+        if 'assignee' in ticket_json:
+            return True
+        else:
+            return False
+
+
+    def unassign_pp_ticket(self, ticket_id: str) -> str:
+        """ making call to unassign pp ticket api which
+            asigns a policy planner ticket on corresponding FMOS box """
+        ticket_json = self.pull_pp_ticket(ticket_id)
+        workflow_packet_task_id = self.get_workflow_packet_task_id(ticket_json)
+        workflow_task_id = self.get_workflow_task_id(ticket_json)
+        pp_tkt_url = self.parser.get('REST', 'unassign_pp_tkt_api_url').format(self.host, self.domain_id, self.workflow_id, workflow_task_id, ticket_id, workflow_packet_task_id)
+        try:
+            resp = requests.put(url=pp_tkt_url,
+                                 headers=self.headers, verify=self.verify_ssl)
+            return str(resp.status_code)
+        except requests.exceptions.HTTPError as e:
+            print("Exception occurred while unassigning policy planner ticket with workflow id '{0}'\n Exception : {1}".
+                  format(workflow_id, e.response.text))
+
     def add_req_pp_ticket(self, ticket_id: str, req_json: dict) -> str:
         ticket_json = self.pull_pp_ticket(ticket_id)
         workflow_task_id = self.get_workflow_task_id(ticket_json)
