@@ -43,7 +43,7 @@ class SecurityManagerApis():
     def siql_query(self, query_type: str, query: str, page_size: int) -> dict:
         """
         Query objects in Security Manage
-        :param query_type: What type of object to query. Options are: secrule, policy, serviceobj, networkobj
+        :param query_type: What type of object to query. Options are: secrule, policy, serviceobj, networkobj, device
         :param query: SIQL query to run
         :param page_size: Number of results to return
         :return: JSON of results
@@ -57,6 +57,50 @@ class SecurityManagerApis():
             print("Exception occurred while while running query\n Exception : {0}".
                   format(e.response.text))
 
+    def create_device_group(self, device_group_name: str) -> dict:
+        """
+        Create device group in Security Manage
+        :param device_group_name: name of device group
+        :return: Response
+        """
+        sm_tkt_url = self.parser.get('REST', 'create_device_group').format(self.host, self.domain_id)
+        payload = {'name': device_group_name, 'domainId': self.domain_id }
+        try:
+            resp = requests.post(url=sm_tkt_url, headers=self.headers, json=payload, verify=self.verify_ssl)
+            return resp
+        except requests.exceptions.HTTPError as e:
+            print("Exception occurred while while creating device group\n Exception : {0}".
+                  format(e.response.text))
+
+    def add_to_device_group(self, device_group_id: str, device_id: str) -> dict:
+        """
+        Add to Device to Device Group
+        :param device_group_id: ID of Device Group
+        :param device_id: Device ID
+        :return: Response
+        """
+        sm_tkt_url = self.parser.get('REST', 'add_device_to_group').format(self.host, self.domain_id, device_group_id, device_id)
+        try:
+            resp = requests.post(url=sm_tkt_url, headers=self.headers, verify=self.verify_ssl)
+            return resp
+        except requests.exceptions.HTTPError as e:
+            print("Exception occurred while while adding device to device group\n Exception : {0}".
+                  format(e.response.text))
+
+    def get_device_group_by_name(self, device_group_name: str) -> dict:
+        """
+        Get Device by Name
+        :param device_group_name: Name of Device Group
+        :return: Response
+        """
+        sm_tkt_url = self.parser.get('REST', 'get_device_group_name').format(self.host, self.domain_id, device_group_name)
+        try:
+            resp = requests.get(url=sm_tkt_url, headers=self.headers, verify=self.verify_ssl)
+            return resp
+        except requests.exceptions.HTTPError as e:
+            print("Exception occurred while while adding device to device group\n Exception : {0}".
+                  format(e.response.text))
+
     def zone_search(self, device_id: str, page_size: int) -> dict:
         """
         Get zones for device
